##  Sorting Transformation Items
Sorting lets you organize transformation items by key attributes. For instance, you can sort by type or status to group related items, or by completion date to identify priorities and track progress.
To sort, click on any column title to sort the items in ascending or descending order based on that column.
